@@ -149,6 +149,7 @@ std::vector<std::pair<std::string, std::string> > GetUsage()
   s.push_back(mp("-setstring name value", "Set constant string name=value"));
   s.push_back(mp("-option file",       "Parse option file at startup"));
   s.push_back(mp("-convert files",     "Convert files into latest binary formats, then exit"));
+  s.push_back(mp("-cpu",               "Report CPU times for all operations"));
   s.push_back(mp("-version",           "Show version number"));
   s.push_back(mp("-info",              "Show detailed version information"));
   s.push_back(mp("-help",              "Show command line usage"));
@@ -364,6 +365,10 @@ void GetOptions(int argc, char *argv[])
         CTX::instance()->batch = 4;
         i++;
       }
+      else if(!strcmp(argv[i] + 1, "cpu")) {
+        Msg::SetInfoCpu(true);
+        i++;
+      }
       else if(!strcmp(argv[i] + 1, "refine")) {
         CTX::instance()->batch = 5;
         i++;
@@ -660,7 +665,7 @@ void GetOptions(int argc, char *argv[])
 #endif
           // convert mesh to latest binary format
           if(GModel::current()->getMeshStatus() > 0){
-            CTX::instance()->mesh.mshFileVersion = 2.0;
+            CTX::instance()->mesh.mshFileVersion = 3.0;
             CTX::instance()->mesh.binary = 1;
             CreateOutputFile(fileName, FORMAT_MSH);
           }
