@@ -60,6 +60,16 @@ void FlGui::wait(){ Fl::wait(); }
 // wait (at most time seconds) for any events, then process them
 void FlGui::wait(double time){ Fl::wait(time); }
 
+void FlGui::setOpenedThroughMacFinder(const std::string &name)
+{
+  _openedThroughMacFinder = name;
+}
+
+std::string FlGui::getOpenedThroughMacFinder()
+{
+  return _openedThroughMacFinder;
+}
+
 static int globalShortcut(int event)
 {
   if(!FlGui::available()) return 0;
@@ -449,6 +459,12 @@ FlGui::FlGui(int argc, char **argv)
 FlGui *FlGui::_instance = 0;
 std::string FlGui::_openedThroughMacFinder = "";
 
+bool FlGui::available()
+{
+  return (_instance != 0);
+}
+
+
 FlGui *FlGui::instance(int argc, char **argv)
 {
   if(!_instance){
@@ -850,14 +866,16 @@ int FlGui::testArrowShortcuts()
     return 1;
   }
 #if defined(HAVE_POPPLER)
-  else if(Fl::test_shortcut(FL_ALT + FL_Up)) {
+  else if(Fl::test_shortcut('u')) {
     gmshPopplerWrapper::setCurrentPageDown();
     drawContext::global()->draw();
+    drawContext::global()->draw();
     return 1;
   }
-  else if(Fl::test_shortcut(FL_ALT + FL_Down)) {
+  else if(Fl::test_shortcut('d')) {
     gmshPopplerWrapper::setCurrentPageUp();
     drawContext::global()->draw();
+    drawContext::global()->draw();
     return 1;
   }
 #endif
