@@ -51,8 +51,8 @@ class GModel
   int _writeMSH2(const std::string &name, double version=2.2, bool binary=false,
                  bool saveAll=false, bool saveParametric=false,
                  double scalingFactor=1.0, int elementStartNum=0,
-                 int saveSinglePartition=0,
-                 bool multipleView=false);
+                 int saveSinglePartition=0, bool multipleView=false,
+                 bool renumberVertices=true);
   int _writePartitionedMSH2(const std::string &baseName, bool binary=false,
                             bool saveAll=false, bool saveParametric=false,
                             double scalingFactor=1.0);
@@ -424,6 +424,7 @@ class GModel
   int removeDuplicateMeshVertices(double tolerance);
 
   // create topology from mesh
+  void createTopologyFromMeshNew();
   void createTopologyFromMesh(int ignoreHoles=0);
   void createTopologyFromRegions(std::vector<discreteRegion*> &discRegions);
   void createTopologyFromFaces(std::vector<discreteFace*> &pFaces, int ignoreHoles=0);
@@ -485,6 +486,9 @@ class GModel
   // optimize the mesh
   int optimizeMesh(const std::string &how);
 
+  // partition the mesh
+  int partitionMesh(int num);
+
   // create partition boundaries
   void createPartitionBoundaries(int createGhostCells, int createAllDims = 0);
 
