@@ -152,8 +152,12 @@ void readMSHPeriodicNodes(FILE *fp, GModel *gm)
       if (completePer) s->correspondingVertices[mv1] = mv2;
     }
     if (!completePer) {
-      if (!s) Msg::Warning("Could not find periodic slave entity %d of dimension %d",slave,dim);
-      if (!m) Msg::Warning("Could not find periodic master entity %d of dimension %d",master,dim);
+      if (!s)
+        Msg::Info("Could not find periodic slave entity %d of dimension %d",
+                     slave, dim);
+      if (!m)
+        Msg::Info("Could not find periodic master entity %d of dimension %d",
+                  master, dim);
     }
   }
 }
@@ -444,6 +448,8 @@ int GModel::readMSH(const std::string &name)
     } while(str[0] != '$');
   }
 
+
+
   // store the elements in their associated elementary entity. If the
   // entity does not exist, create a new (discrete) one.
   for(int i = 0; i < (int)(sizeof(elements) / sizeof(elements[0])); i++)
@@ -562,6 +568,8 @@ static void writeElementsMSH(FILE *fp, GModel *model, GEntity *ge, std::vector<T
   }
 }
 
+//#warning periodic nodes are not correct in case the nodes are renumbered
+
 void writeMSHPeriodicNodes(FILE *fp, std::vector<GEntity*> &entities)
 {
   int count = 0;
