@@ -52,90 +52,14 @@ MElement::MElement(int num, int part) : _visible(1)
   }
 }
 
-MElement* MElement::createElement(int tag, const std::vector<MVertex*> &vertices,
-                                  int num, int part)
+void MElement::setTolerance(const double tol)
 {
-  const int type = ElementType::ParentTypeFromTag(tag);
-  const int order = ElementType::OrderFromTag(tag);
-  const bool serendipity = ElementType::SerendipityFromTag(tag) > 1;
+  _isInsideTolerance = tol;
+}
 
-  if (order == 0) {
-    Msg::Error("p0 elements can not be created (tag %d)", tag);
-    return NULL;
-  }
-
-  switch (type) {
-
-  case TYPE_PNT:
-    return new MPoint(vertices, num, part);
-
-  case TYPE_LIN:
-    if (order == 1)
-      return new MLine(vertices, num, part);
-    else if (order == 2)
-      return new MLine3(vertices, num, part);
-    else
-      return new MLineN(vertices, num, part);
-
-  case TYPE_TRI:
-    if (order == 1)
-      return new MTriangle(vertices, num, part);
-    else if (order == 2)
-      return new MTriangle6(vertices, num, part);
-    else
-      return new MTriangleN(vertices, order, num, part);
-
-  case TYPE_QUA:
-    if (order == 1)
-      return new MQuadrangle(vertices, num, part);
-    else if (order == 2 && serendipity)
-      return new MQuadrangle8(vertices, num, part);
-    else if (order == 2)
-      return new MQuadrangle9(vertices, num, part);
-    else
-      return new MQuadrangleN(vertices, order, num, part);
-
-  case TYPE_TET:
-    if (order == 1)
-      return new MTetrahedron(vertices, num, part);
-    else if (order == 2)
-      return new MTetrahedron10(vertices, num, part);
-    else
-      return new MTetrahedronN(vertices, order, num, part);
-
-  case TYPE_PYR:
-    if (order == 1)
-      return new MPyramid(vertices, num, part);
-    else
-      return new MPyramidN(vertices, order, num, part);
-
-  case TYPE_PRI:
-    if (order == 1)
-      return new MPrism(vertices, num, part);
-    else if (order == 2 && serendipity)
-      return new MPrism15(vertices, num, part);
-    else if (order == 2)
-      return new MPrism18(vertices, num, part);
-    else
-      return new MPrismN(vertices, order, num, part);
-
-  case TYPE_TRIH:
-    return new MTrihedron(vertices, num, part);
-
-  case TYPE_HEX:
-    if (order == 1)
-      return new MHexahedron(vertices, num, part);
-    else if (order == 2 && serendipity)
-      return new MHexahedron20(vertices, num, part);
-    else if (order == 2)
-      return new MHexahedron27(vertices, num, part);
-    else
-      return new MHexahedronN(vertices, order, num, part);
-
-  default:
-    break;
-  }
-  return NULL;
+double MElement::getTolerance()
+{
+  return _isInsideTolerance;
 }
 
 void MElement::_getEdgeRep(MVertex *v0, MVertex *v1,
@@ -202,16 +126,6 @@ double MElement::rhoShapeMeasure()
     return 0.;
 }
 
-double MElement::metricShapeMeasure()
-{
-  return MetricBasis::getMinRCorner(this);
-}
-
-double MElement::metricShapeMeasure2()
-{
-  return MetricBasis::getMinR(this);
-}
-
 double MElement::maxDistToStraight() const
 {
   const nodalBasis *lagBasis = getFunctionSpace();
@@ -235,10 +149,10 @@ double MElement::maxDistToStraight() const
   return maxdx;
 }
 
-double MElement::minAnisotropyMeasure(bool knownValid, bool reversedOK)
+double MElement::minIsotropyMeasure(bool knownValid, bool reversedOK)
 {
 #if defined(HAVE_MESH)
-  return jacobianBasedQuality::minAnisotropyMeasure(this, knownValid, reversedOK);
+  return jacobianBasedQuality::minIsotropyMeasure(this, knownValid, reversedOK);
 #else
   return 0.;
 #endif
