@@ -147,7 +147,7 @@ class MHexahedron : public MElement {
   }
   virtual bool isInside(double u, double v, double w) const
   {
-    double tol = _isInsideTolerance;
+    double tol = getTolerance();
     if(u < -(1. + tol) || v < -(1. + tol) || w < -(1. + tol) ||
        u > (1. + tol) || v > (1. + tol) || w > (1. + tol))
       return false;
