@@ -147,7 +147,7 @@ class MTriangle : public MElement {
   }
   virtual bool isInside(double u, double v, double w) const
   {
-    double tol = _isInsideTolerance;
+    double tol = getTolerance();
     if(u < (-tol) || v < (-tol) || u > ((1. + tol) - v) || fabs(w) > tol)
       return false;
     return true;
