@@ -14,14 +14,14 @@
 #include <stack>
 #include <queue>
 
+#include "MPoint.h"
+
 #if defined(HAVE_METIS)
 extern "C" {
 #include <metis.h>
 }
 #endif
 
-int cp=0;
-
 discreteFace::discreteFace(GModel *model, int num) : GFace(model, num)
 {
   Surface *s = Create_Surface(num, MSH_SURF_DISCRETE);
@@ -112,33 +112,37 @@ void discreteFace::secondDer(const SPoint2 &param,
 void discreteFace::createGeometry()
 {
   checkAndFixOrientation();
-  int order = 1;
-  int nPart = 2;
-  double eta = .125;
 
 #if defined(HAVE_SOLVER) && defined(HAVE_ANN)
-
+  int order = 1;
+  int nPart = 2;
+  double eta = 5/(2.*3.14);
   if (!_atlas.empty())return;
 
+  double dtSplit = 0.0;
+
   int id=1;
   std::stack<triangulation*>  toSplit;
   std::vector<triangulation*> toParam;
+
   std::vector<MElement*> tem(triangles.begin(),triangles.end());
-
-  triangulation* init = new triangulation(tem,this);
+  triangulation* init = new triangulation(-1, tem,this);
   toSplit.push(init);
-  if((toSplit.top())->genus()!=0 || (toSplit.top())->aspectRatio() < eta || (toSplit.top())->seamPoint){
-
+  if((toSplit.top())->genus()!=0 || (toSplit.top())->aspectRatio() > eta ||
+				       (toSplit.top())->seamPoint){
     while( !toSplit.empty()){
       std::vector<triangulation*> part;
       triangulation* tosplit = toSplit.top();
       toSplit.pop();
 
+      double ts0 = Cpu();
       split(tosplit,part,nPart);
+      double ts1 = Cpu();
+      dtSplit += ts1-ts0;
       delete tosplit;
 
       for(unsigned int i=0; i<part.size(); i++){
-	if(part[i]->genus()!=0 || part[i]->aspectRatio() < eta || part[i]->seamPoint)
+	if(part[i]->genus()!=0 || part[i]->aspectRatio() > eta || part[i]->seamPoint)
 	  toSplit.push(part[i]);
 	else{
 	  toParam.push_back(part[i]);
@@ -152,13 +156,25 @@ void discreteFace::createGeometry()
     toSplit.top()->idNum=id++;
   }
   updateTopology(toParam);
+
   for(unsigned int i=0; i<toParam.size(); i++){
+    /*
+    char name[256];
+    sprintf(name,"map%d.pos",i);
+    toParam[i]->print(name,i);
+    */
     fillHoles(toParam[i]);
-    std::vector<MElement*> mytri = toParam[i]->tri;
+    //sprintf(name,"mapFilled%d.pos",i);
+    //toParam[i]->print(name, toParam[i]->idNum);
+  }
+
+  for(unsigned int i=0; i<toParam.size(); i++){
     discreteDiskFace *df = new discreteDiskFace (this,toParam[i], order,(_CAD.empty() ? NULL : &_CAD));
+    df->printAtlasMesh();
     df->replaceEdges(toParam[i]->my_GEdges);
     _atlas.push_back(df);
   }
+
 #endif
 }
 
@@ -209,11 +225,14 @@ void discreteFace::mesh(bool verbose)
 {
 #if defined(HAVE_ANN) && defined(HAVE_SOLVER) && defined(HAVE_MESH)
   if (!CTX::instance()->meshDiscrete) return;
+
   for (unsigned int i=0;i<_atlas.size();i++){
     Msg::Info("Discrete Face %d is going to be meshed",i);
-    printAtlasMesh(_atlas[i]->discrete_triangles,i);
-    _atlas[i]->mesh(verbose);
-    //printAtlasMesh(_atlas[i],i);
+    _atlas[i]->mesh(verbose);/*
+    const char *name = "atlas%d";
+    char filename[256];
+    sprintf(filename,name,i);t0
+    _atlas[i]->printPhysicalMesh(filename);*/
   }
 
   gatherMeshes();
@@ -221,87 +240,11 @@ void discreteFace::mesh(bool verbose)
 #endif
 }
 
-void discreteFace::printAtlasMesh(std::vector<MElement*> elm, int I)
+
+
+void discreteFace::checkAndFixOrientation()
 {
 
-  std::map<MVertex*,int> mv2int;
-  char buffer[16];
-  sprintf(buffer,"atlas_mesh%d.msh",I);
-  FILE* pmesh = Fopen(buffer,"w");
-
-  std::set<MVertex*> meshvertices;
-
-  for(unsigned int i=0; i<elm.size(); ++i){
-    MElement* tri = elm[i];
-    for(unsigned int j=0; j<3; j++)
-      if (meshvertices.find(tri->getVertex(j))==meshvertices.end()) meshvertices.insert(tri->getVertex(j));
-  }
-
-  fprintf(pmesh,"$MeshFormat\n2.2 0 8\n$EndMeshFormat\n$Nodes\n%u\n",(unsigned int)meshvertices.size());
-  int count = 1;
-  for(std::set<MVertex*>::iterator it = meshvertices.begin(); it!=meshvertices.end(); ++it){
-    fprintf(pmesh,"%d %f %f %f\n",count,(*it)->x(),(*it)->y(),(*it)->z());
-    mv2int[*it] = count;
-    count++;
-  }
-  fprintf(pmesh,"$EndNodes\n$Elements\n%u\n",(unsigned int)elm.size());
-  for(unsigned int i=0; i<elm.size(); i++){
-    MElement* tri = elm[i];
-    fprintf(pmesh,"%d 2 2 0 0",i+1);
-    for(int j=0; j<3; j++){
-      MVertex* mv = tri->getVertex(j);
-      fprintf(pmesh," %d",mv2int[mv]);
-    }
-    fprintf(pmesh,"\n");
-  }
-  fprintf(pmesh,"$EndElements\n");
-  fclose(pmesh);
-
-}
-
-
-
-void discreteFace::printAtlasMesh(discreteDiskFace* ddf, int I)
-{
-#if defined(HAVE_SOLVER) && defined(HAVE_ANN)
-  std::map<MVertex*,int> mv2int;
-  char buffer[16];
-  sprintf(buffer,"atlas_mesh%d.msh",I);
-  FILE* pmesh = Fopen(buffer,"w");
-
-  std::set<MVertex*> meshvertices;
-
-  for(unsigned int i=0; i<ddf->triangles.size(); ++i){
-    MTriangle* tri = ddf->triangles[i];
-    for(unsigned int j=0; j<3; j++)
-      if (meshvertices.find(tri->getVertex(j))==meshvertices.end()) meshvertices.insert(tri->getVertex(j));
-  }
-
-  fprintf(pmesh,"$MeshFormat\n2.2 0 8\n$EndMeshFormat\n$Nodes\n%u\n",(unsigned int)meshvertices.size());
-  int count = 1;
-  for(std::set<MVertex*>::iterator it = meshvertices.begin(); it!=meshvertices.end(); ++it){
-    fprintf(pmesh,"%d %f %f %f\n",count,(*it)->x(),(*it)->y(),(*it)->z());
-    mv2int[*it] = count;
-    count++;
-  }
-  fprintf(pmesh,"$EndNodes\n$Elements\n%u\n",(unsigned int)ddf->triangles.size());
-  for(unsigned int i=0; i<ddf->triangles.size(); i++){
-    MTriangle* tri = ddf->triangles[i];
-    fprintf(pmesh,"%d 2 2 0 0",i+1);
-    for(int j=0; j<3; j++){
-      MVertex* mv = tri->getVertex(j);
-      fprintf(pmesh," %d",mv2int[mv]);
-    }
-    fprintf(pmesh,"\n");
-  }
-  fprintf(pmesh,"$EndElements\n");
-  fclose(pmesh);
-#endif
-}
-
-
-void discreteFace::checkAndFixOrientation(){
-
   // first of all, all the triangles have to be oriented in the same way
   std::map<MEdge,std::vector<MElement*>,Less_Edge> ed2tri; // edge to 1 or 2 triangle(s)
 
@@ -381,34 +324,38 @@ void discreteFace::checkAndFixOrientation(){
   } // end while
 }
 
+
 void discreteFace::setupDiscreteVertex(GVertex*dv,MVertex*mv,std::set<MVertex*>*trash){
-  dv->mesh_vertices.push_back(mv);
   mv->setEntity(dv);
+  dv->mesh_vertices.push_back(mv);
   this->model()->add(dv);
+  dv->points.push_back(new MPoint(dv->mesh_vertices.back()));
   if (trash) trash->insert(mv);
 }
 
-void discreteFace::setupDiscreteEdge(discreteEdge*de,std::vector<MLine*>mlines,std::set<MVertex*>*trash){
+void discreteFace::setupDiscreteEdge(discreteEdge*de,std::vector<MLine*>mlines,
+                                     std::set<MVertex*>*trash)
+{
   this->model()->add(de);// new GEdge
-  de->lines = mlines;// associated MLine's
+  de->setTopo(mlines);// associated MLine's
   for(unsigned int i=1; i<mlines.size(); i++){//not the first vertex of the GEdge (neither the last one)
     mlines[i]->getVertex(0)->setEntity(de);
     de->mesh_vertices.push_back(mlines[i]->getVertex(0));
     if(trash) trash->insert(mlines[i]->getVertex(0));
   }
   de->createGeometry();
-  if(de->getBeginVertex()->mesh_vertices[0]!=de->lines[0]->getVertex(0))// small hack ... #mark
-    de->reverse();
+  de->getBeginVertex()->addEdge(de);
+  de->getEndVertex()->addEdge(de);
+
 }
 
-
 // split old GEdge's
-void discreteFace::splitDiscreteEdge ( GEdge *de , GVertex *gv, discreteEdge* newE[2]){
-
+void discreteFace::splitDiscreteEdge(GEdge *de , GVertex *gv, discreteEdge* newE[2])
+{
   MVertex *vend = de->getEndVertex()->mesh_vertices[0];
 
-  newE[0] = new discreteEdge (de->model(),NEWLINE(),de->getBeginVertex(),gv);
-  newE[1] = new discreteEdge (de->model(),NEWLINE(),gv, de->getEndVertex());
+  newE[0] = new discreteEdge (de->model(),model()->getMaxElementaryNumber(1) + 1,de->getBeginVertex(),gv);
+  newE[1] = new discreteEdge (de->model(),model()->getMaxElementaryNumber(1) + 1,gv, de->getEndVertex());
 
   int current = 0;
   std::vector<MLine*> mlines;
@@ -422,6 +369,8 @@ void discreteFace::splitDiscreteEdge ( GEdge *de , GVertex *gv, discreteEdge* ne
       current++;
     }
   }
+  de->getBeginVertex()->delEdge(de);
+  de->getEndVertex()->delEdge(de);
   de->mesh_vertices.clear();
   de->lines.clear();
 
@@ -452,7 +401,8 @@ void discreteFace::splitDiscreteEdge ( GEdge *de , GVertex *gv, discreteEdge* ne
 }
 
 
-void discreteFace::split(triangulation* trian,std::vector<triangulation*> &partition,int nPartitions)
+void discreteFace::split(triangulation* trian,std::vector<triangulation*> &partition,
+                         int nPartitions)
 {
 #if defined(HAVE_SOLVER) && defined(HAVE_ANN) && defined(HAVE_METIS)
 
@@ -514,7 +464,7 @@ void discreteFace::split(triangulation* trian,std::vector<triangulation*> &parti
       for(int j=0; j<3; j++){// adjacency from edges
 	MEdge ed = current->getEdge(j);
 	if(trian->ed2tri[ed].size()>1){
-	  std::vector<int> oldnums = trian->ed2tri[ed];
+	  const std::vector<int> &oldnums = trian->ed2tri[ed];
 	  int on = trian->tri[oldnums[0]] == current ? oldnums[1] : oldnums[0];
 	  if(check_todo.find(trian->tri[on])==check_todo.end() && el2part[trian->tri[on]]==p){
 	    my_todo.push(trian->tri[on]);
@@ -540,14 +490,11 @@ void discreteFace::split(triangulation* trian,std::vector<triangulation*> &parti
     }
   }// end for p
   for(int i=0; i<nPartitions; i++)// new triangulation of the connected parts
-    partition.push_back(new triangulation(elem[i],this));
-
-
+    partition.push_back(new triangulation(i, elem[i],this));
 
 #endif
 }
 
-
 void discreteFace::updateTopology(std::vector<triangulation*>&partition)
 {
 #if defined(HAVE_SOLVER) && defined(HAVE_ANN) && defined(HAVE_METIS)
@@ -558,13 +505,13 @@ void discreteFace::updateTopology(std::vector<triangulation*>&partition)
   std::set<MVertex*> todelete; // vertices that do not belong to the GFace anymore
   std::set<GEdge*> gGEdges(l_edges.begin(),l_edges.end());// initial GEdges of the GFace (to be updated)
 
-  for(int i=0; i<nPartitions; i++){// each part is going ot be compared with the other ones
-    std::set<MEdge,Less_Edge> bordi = partition[i]->borderEdg;// edges defining the border(s) of the i-th new triangulation
+  for(int i=0; i<nPartitions; i++){// each part is going to be compared with the other ones
+    const std::set<MEdge,Less_Edge> &bordi = partition[i]->borderEdg;// edges defining the border(s) of the i-th new triangulation
     for(int ii=i+1; ii<nPartitions; ii++){// compare to the ii-th partitions, with ii > i since ii < i have already been compared
       std::map<MVertex*,MLine*> v02edg;//first vertex of the MLine
       std::set<MVertex*> first, last;
+      const std::set<MEdge,Less_Edge> &bii = partition[ii]->borderEdg;// edges defining the border(s) of the ii-th new triangulation
       for(std::set<MEdge,Less_Edge>::iterator ie = bordi.begin(); ie != bordi.end(); ++ie){// MEdge by MEdge of the i-th triangulation border(s)
-	std::set<MEdge,Less_Edge> bii = partition[ii]->borderEdg;// edges defining the border(s) of the ii-th new triangulation
 	if(bii.find(*ie)!=bii.end()){// if the border edge is common to both triangulations, then it is a future GEdge - composed of MLine's
 	  v02edg[ie->getVertex(0)] = new MLine(ie->getVertex(0),ie->getVertex(1));// a new MLine is created
 
@@ -595,15 +542,15 @@ void discreteFace::updateTopology(std::vector<triangulation*>&partition)
 	mvt.resize(2);
 	mvt[0] = *itf;
 	mvt[1] = cv0;
-
 	// creation of the GVertex, for new nonloop GEdge's
 	for(int imvt=0; imvt<2; imvt++){
 	  std::set<GEdge*>::iterator oe=gGEdges.begin();// find the old GEdge that has the current new GVertex
 	  while(oe !=gGEdges.end() && mvt[imvt]->onWhat() != *oe && mvt[imvt]->onWhat() != (*oe)->getBeginVertex() && mvt[imvt]->onWhat() != (*oe)->getEndVertex())
 	    ++oe;
 
+
 	  if (oe == gGEdges.end()){// not on an existing GEdge: new internal GVertex
-	    v[imvt] = new discreteVertex (this->model(),NEWPOINT());
+	    v[imvt] = new discreteVertex (this->model(),model()->getMaxElementaryNumber(0) + 1);
 	    setupDiscreteVertex(v[imvt],mvt[imvt],&todelete);
 	  }
 	  else{// on an existing GEdge
@@ -613,7 +560,7 @@ void discreteFace::updateTopology(std::vector<triangulation*>&partition)
 	    else if (mvt[imvt] == onit->getEndVertex()->mesh_vertices[0])
 	      v[imvt] = onit->getEndVertex();
 	    else{
-	      v[imvt] = new discreteVertex (this->model(),NEWPOINT());
+	      v[imvt] = new discreteVertex (this->model(),model()->getMaxElementaryNumber(0) + 1);
 	      setupDiscreteVertex(v[imvt],mvt[imvt],NULL);
 	      discreteEdge* de[2];
 	      splitDiscreteEdge(onit,v[imvt],de);
@@ -624,10 +571,9 @@ void discreteFace::updateTopology(std::vector<triangulation*>&partition)
 	  }// end else oe==end()
 	}// end imvt
 	// the new GEdge can be created with its GVertex
-	discreteEdge* internalE = new discreteEdge (this->model(),NEWLINE(),v[0],v[1]);
+	discreteEdge* internalE = new discreteEdge (this->model(),model()->getMaxElementaryNumber(1) + 1,v[0],v[1]);
 	setupDiscreteEdge(internalE,myLines,&todelete);
-	partition[i]->my_GEdges.push_back(internalE);
-	partition[ii]->my_GEdges.push_back(internalE);
+	gGEdges.insert(internalE);
 
 	first.erase(itf);// next first vertex of a nonloop GEdge
       }//end while first.empty()
@@ -642,12 +588,11 @@ void discreteFace::updateTopology(std::vector<triangulation*>&partition)
 	  v02edg.erase(cv0);// update the container
 	  cv0 = my_MLines.back()->getVertex(1);// next MLine of the loop
 	}
-	v = new discreteVertex (this->model(),NEWPOINT());
+	v = new discreteVertex (this->model(),model()->getMaxElementaryNumber(0) + 1);
 	setupDiscreteVertex(v,cv0,&todelete);
-	discreteEdge* gloop = new discreteEdge (this->model(),NEWLINE(),v,v);
+	discreteEdge* gloop = new discreteEdge (this->model(),model()->getMaxElementaryNumber(1) + 1,v,v);
 	setupDiscreteEdge(gloop,my_MLines,&todelete);
-	partition[i]->my_GEdges.push_back(gloop);
-	partition[ii]->my_GEdges.push_back(gloop);
+	gGEdges.insert(gloop);
       }// end while v02edg.empty()
     }//end for ii
   }// end for i
@@ -661,7 +606,7 @@ void discreteFace::updateTopology(std::vector<triangulation*>&partition)
       std::set<MEdge,Less_Edge> bordi = partition[i]->borderEdg;
       if(bordi.find(edTest)!=bordi.end()){
 	partition[i]->my_GEdges.push_back(ile);
-	break;
+	//break;
       }
     }
   }
@@ -678,29 +623,61 @@ void discreteFace::updateTopology(std::vector<triangulation*>&partition)
 #endif
 }
 
-
 void discreteFace::fillHoles(triangulation* trian)
-{
+{// #improveme moving the center
 #if defined(HAVE_SOLVER) && defined(HAVE_ANN)
   std::map<double,std::vector<MVertex*> > bords = trian->bord;
   std::map<double,std::vector<MVertex*> >::reverse_iterator it = bords.rbegin();
   ++it;
   for(; it!=bords.rend(); ++it){
-    double x[3] = {0.,0.,0.};
+    SPoint3 x(0.,0.,0.);
     std::vector<MVertex*> mv = it->second;
     for(unsigned int j=0; j<mv.size(); j++){
-      x[0] += mv[j]->x();
-      x[1] += mv[j]->y();
-      x[2] += mv[j]->z();
+      SPoint3 v0, v1;
+      if(j==0){
+	SPoint3 v(mv[mv.size()-1]->x(),mv[mv.size()-1]->y(),mv[mv.size()-1]->z());
+	v0 = v;
+	SPoint3 v_(mv[j+1]->x(),mv[j+1]->y(),mv[j+1]->z());
+	v1 = v_;
+      }
+      else if (j==mv.size()-1){
+	SPoint3 v(mv[j-1]->x(),mv[j-1]->y(),mv[j-1]->z());
+	v0 = v;
+	SPoint3 v_(mv[0]->x(),mv[0]->y(),mv[0]->z());
+	v1 = v_;
+      }
+      else{
+	SPoint3 v(mv[j-1]->x(),mv[j-1]->y(),mv[j-1]->z());
+	v0 = v;
+	SPoint3 v_(mv[j+1]->x(),mv[j+1]->y(),mv[j+1]->z());
+	v1 = v_;
+      }
+      SPoint3 vpp(mv[j]->x(),mv[j]->y(),mv[j]->z());
+      SVector3 v00(vpp,v0);
+      SVector3 v11(v1,vpp);
+      x += vpp*(norm(v00)+norm(v11));
     }
-    x[0] /= mv.size(); x[1] /= mv.size(); x[2] /= mv.size();
-    MVertex* center = new MVertex(x[0],x[1],x[2]);
+    x *= .5/it->first;
+    MVertex* center = new MVertex(x.x(),x.y(),x.z());
     this->mesh_vertices.push_back(center);
-    center->setEntity(this);
     trian->vert.insert(center);
-    for(unsigned int j=1; j<mv.size(); j++)
+    SVector3 nmean(0.,0.,0.);
+    for(unsigned int j=1; j<mv.size(); j++){
       addTriangle(trian,new MTriangle(mv[j],mv[j-1],center));
+      SVector3 temp0(center->x()-mv[j]->x(),center->y()-mv[j]->y(),center->z()-mv[j]->z());
+      SVector3 temp1(center->x()-mv[j-1]->x(),center->y()-mv[j-1]->y(),center->z()-mv[j-1]->z());
+      SVector3 temp(crossprod(temp0,temp1));
+      nmean += temp;
+    }
     addTriangle(trian,new MTriangle(mv[0],mv[mv.size()-1],center));
+    SVector3 temp0(center->x()-mv[0]->x(),center->y()-mv[0]->y(),center->z()-mv[0]->z());
+    SVector3 temp1(center->x()-mv[mv.size()-1]->x(),center->y()-mv[mv.size()-1]->y(),center->z()-mv[mv.size()-1]->z());
+    SVector3 temp(crossprod(temp0,temp1));
+    nmean += temp;
+    nmean *= 1./(norm(nmean)*mv.size());
+    MVertex update(center->x()+nmean.x(),center->y()+nmean.y(),center->z()+nmean.z());
+    *center = update;
+    center->setEntity(this);
   }
 #endif
 }
@@ -708,21 +685,16 @@ void discreteFace::fillHoles(triangulation* trian)
 void discreteFace::addTriangle(triangulation* trian, MTriangle* t)
 {
 #if defined(HAVE_SOLVER) && defined(HAVE_ANN)
-  // #mark quid borders ?
   for(int i=0; i<3; i++){
     MEdge ed = t->getEdge(i);
-    trian->ed2tri[ed].push_back(trian->tri.size());
+    int n = trian->tri.size();
+    trian->fillingHoles.insert(n);
+    trian->ed2tri[ed].push_back(n);
   }
   trian->tri.push_back(t);
 #endif
 }
 
-
-// delete all discrete disk faces
-//void discreteFace::deleteAtlas() {
-//}
-//---------------------------------------------------------
-
 void discreteFace::writeGEO(FILE *fp)
 {
   fprintf(fp, "Discrete Face(%d) = {",tag());
