@@ -20,6 +20,7 @@
 #include "GEdge.h"
 #include "gmshRegion.h"
 #include "MLine.h"
+#include "MPoint.h"
 #include "MTriangle.h"
 #include "MQuadrangle.h"
 #include "MTetrahedron.h"
@@ -56,6 +57,41 @@ class splitQuadRecovery {
   {
     _data.insert(std::make_pair(ge, std::make_pair(v,f)));
   }
+  void relocateVertices(GRegion *region, int niter) {
+    if(empty()) return ;
+    v2t_cont adj;
+    buildVertexToElement(region->tetrahedra, adj);
+    buildVertexToElement(region->pyramids, adj);
+    buildVertexToElement(region->prisms, adj);
+    buildVertexToElement(region->hexahedra, adj);
+
+    double minQual     = 1;
+    double minQualOpti = 1;
+
+    std::list<GFace*> faces = region->faces();
+
+    for (int iter=0; iter < niter+2;iter++){
+      for (std::list<GFace*>::iterator it = faces.begin(); it != faces.end(); ++it){
+	for (std::multimap<GEntity*, std::pair<MVertex*,MFace> >::iterator it2 =
+	       _data.lower_bound(*it); it2 != _data.upper_bound(*it) ; ++it2){
+	  const MFace &f = it2->second.second;
+	  MVertex *v = it2->second.first;
+	  MPyramid p (f.getVertex(0), f.getVertex(1), f.getVertex(2), f.getVertex(3), v);
+	  minQual = std::min(minQual, fabs(p.minSICNShapeMeasure()));
+	  std::vector<MElement*> e = adj[v];
+	  e.push_back(&p);
+	  v->setEntity (region);
+	  double relax = std::min((double)(iter+1)/niter, 1.0);
+	  //	  printf("%g (%d) --> ",e.size(),p.minSICNShapeMeasure());
+	  _relocateVertexGolden( v, e, relax);
+	  minQualOpti = std::min(minQualOpti, fabs(p.minSICNShapeMeasure()));
+	  //	  printf("%g \n",p.minSICNShapeMeasure());
+	  v->setEntity (*it);
+	}
+      }
+    }
+    //printf("relocation improves %g --> %g\n", minQual, minQualOpti);
+  }
   int buildPyramids(GModel *gm)
   {
     if(empty()) return 0;
@@ -202,7 +238,7 @@ void buildTetgenStructure(GRegion *gr, tetgenio &in, std::vector<MVertex*> &numb
   {
     std::list<GEdge*> embe = gr->embeddedEdges();
     for (std::list<GEdge*>::iterator it = embe.begin(); it != embe.end(); ++it){
-      for (unsigned int i=0;i<(*it)->lines.size();i++){
+      for (unsigned int i = 0; i < (*it)->lines.size(); i++){
 	MEdge me ((*it)->lines[i]->getVertex(0),(*it)->lines[i]->getVertex(1));
 	allBoundingEdges[me] = *it;
 	allBoundingVertices.insert((*it)->lines[i]->getVertex(0));
@@ -211,13 +247,23 @@ void buildTetgenStructure(GRegion *gr, tetgenio &in, std::vector<MVertex*> &numb
     }
   }
 
+  // embedded vertices
+  {
+    std::list<GVertex*> embv = gr->embeddedVertices();
+    for (std::list<GVertex*>::iterator it = embv.begin(); it != embv.end(); ++it){
+      for (unsigned int i = 0; i < (*it)->points.size(); i++){
+	allBoundingVertices.insert((*it)->points[i]->getVertex(0));
+      }
+    }
+  }
+
   getBoundingInfoAndSplitQuads(gr, allBoundingFaces, allBoundingVertices, sqr);
 
   //// TEST
   {
-    std::vector<MVertex*>ALL;
-    std::vector<MTetrahedron*> MESH;
-    ALL.insert(ALL.begin(),allBoundingVertices.begin(),allBoundingVertices.end());
+    //    std::vector<MVertex*>ALL;
+    //    std::vector<MTetrahedron*> MESH;
+    //    ALL.insert(ALL.begin(),allBoundingVertices.begin(),allBoundingVertices.end());
     //    delaunayMeshIn3D (ALL,MESH);
     //    exit(1);
   }
@@ -230,7 +276,7 @@ void buildTetgenStructure(GRegion *gr, tetgenio &in, std::vector<MVertex*> &numb
   in.pointlist = new REAL[in.numberofpoints * 3];
   in.pointmarkerlist = NULL;
 
-  printf("nbvertices_filler =%d\n",nbvertices_filler);
+  //printf("nbvertices_filler =%d\n",nbvertices_filler);
 
   std::set<MVertex*>::iterator itv = allBoundingVertices.begin();
   int I = 1;
@@ -406,7 +452,6 @@ void TransferTetgenMesh(GRegion *gr, tetgenio &in, tetgenio &out,
 
       for(int j = 0; j < 3; j++){
         if (out.trifacelist[i * 3 + j] - 1 >= initialSize){
-          printf("aaaaaaaaaaaaaaargh\n");
           //        if(v[j]->onWhat()->dim() == 3){
           v[j]->onWhat()->mesh_vertices.erase
             (std::find(v[j]->onWhat()->mesh_vertices.begin(),
@@ -456,13 +501,13 @@ void TransferTetgenMesh(GRegion *gr, tetgenio &in, tetgenio &out,
 
 bool CreateAnEmptyVolumeMesh(GRegion *gr)
 {
-  printf("creating an empty volume mesh\n");
+  //printf("creating an empty volume mesh\n");
   splitQuadRecovery sqr;
   tetgenio in, out;
   std::vector<MVertex*> numberedV;
   char opts[128];
   buildTetgenStructure(gr, in, numberedV, sqr);
-  printf("tetgen structure created\n");
+  //printf("tetgen structure created\n");
   sprintf(opts, "-Ype%sT%g",
           (Msg::GetVerbosity() < 3) ? "Q" : (Msg::GetVerbosity() > 6) ? "V" : "",
           CTX::instance()->mesh.toleranceInitialDelaunay);
@@ -473,7 +518,7 @@ bool CreateAnEmptyVolumeMesh(GRegion *gr)
     Msg::Error("Self intersecting surface mesh");
     return false;
   }
-  printf("creating an empty volume mesh done\n");
+  //printf("creating an empty volume mesh done\n");
   TransferTetgenMesh(gr, in, out, numberedV);
   return true;
 }
@@ -564,6 +609,10 @@ void MeshDelaunayVolumeTetgen(std::vector<GRegion*> &regions)
   // restore the initial set of faces
   gr->set(faces);
 
+  // FIXME: this screws up refinement of standard meshes
+  //insertVerticesInRegion(gr,0,true);
+  //sqr.relocateVertices(gr,3);
+
   // now do insertion of points
   if(CTX::instance()->mesh.algo3d == ALGO_3D_FRONTAL_DEL)
     bowyerWatsonFrontalLayers(gr, false);
@@ -579,9 +628,9 @@ void MeshDelaunayVolumeTetgen(std::vector<GRegion*> &regions)
       insertVerticesInRegion(gr,2000000000,true);
     }
   }
-
+  // crete an initial mesh
   if (sqr.buildPyramids (gr->model())){
-    RelocateVertices (regions);
+    RelocateVertices(regions, 3);
   }
 }
 
@@ -606,11 +655,30 @@ static void MeshDelaunayVolumeNewCode(std::vector<GRegion*> &regions)
     f = regions[i]->embeddedFaces();
     allFacesSet.insert(f.begin(), f.end());
   }
-
   std::list<GFace*> allFaces;
   allFaces.insert(allFaces.end(), allFacesSet.begin(), allFacesSet.end());
   gr->set(allFaces);
 
+  std::set<GEdge*> allEmbEdgesSet;
+  for(unsigned int i = 0; i < regions.size(); i++){
+    std::list<GEdge*> e = regions[i]->embeddedEdges();
+    allEmbEdgesSet.insert(e.begin(), e.end());
+  }
+  std::list<GEdge*> allEmbEdges;
+  allEmbEdges.insert(allEmbEdges.end(), allEmbEdgesSet.begin(), allEmbEdgesSet.end());
+  std::list<GEdge*> oldEmbEdges = gr->embeddedEdges();
+  gr->embeddedEdges() = allEmbEdges;
+
+  std::set<GVertex*> allEmbVerticesSet;
+  for(unsigned int i = 0; i < regions.size(); i++){
+    std::list<GVertex*> e = regions[i]->embeddedVertices();
+    allEmbVerticesSet.insert(e.begin(), e.end());
+  }
+  std::list<GVertex*> allEmbVertices;
+  allEmbVertices.insert(allEmbVertices.end(), allEmbVerticesSet.begin(), allEmbVerticesSet.end());
+  std::list<GVertex*> oldEmbVertices = gr->embeddedVertices();
+  gr->embeddedVertices() = allEmbVertices;
+
   try{
     meshGRegionBoundaryRecovery(gr);
     /*
@@ -641,8 +709,10 @@ static void MeshDelaunayVolumeNewCode(std::vector<GRegion*> &regions)
     ++itf;
   }
 
-  // restore the initial set of faces
+  // restore the initial set of faces and embedded edges/vertices
   gr->set(faces);
+  gr->embeddedEdges() = oldEmbEdges;
+  gr->embeddedVertices() = oldEmbVertices;
 
   // now do insertion of points
   if(CTX::instance()->mesh.oldRefinement){
@@ -852,7 +922,7 @@ int intersect_line_triangle(double X[3], double Y[3], double Z[3] ,
     return 0;
   }
   else{
-    printf("non robust stuff\n");
+    //printf("non robust stuff\n");
     // the intersection is not robust, try another triangle
     return -10000;
   }
