@@ -5,7 +5,7 @@
 #include "linearSystemPETSc.h"
 
 #if ((PETSC_VERSION_RELEASE == 0) || ((PETSC_VERSION_MAJOR == 3) && (PETSC_VERSION_MINOR >= 7)))
-#define PetscOptionsGetInt(A, B, C, D) PetscOptionsGetInt(NULL, A, B, C, D);
+#define PetscOptionsGetInt(A, B, C, D) PetscOptionsGetInt(NULL, A, B, C, D)
 #define PetscOptionsInsertString(A) PetscOptionsInsertString(NULL, A)
 #endif
 
