@@ -3,12 +3,11 @@
 
 #import "ModelViewController.h"
 #import "drawContext.h"
-#import "iosGModel.h"
+#import "iosUtils.h"
 #import "Utils.h"
 
 #import "AppDelegate.h"
 
-
 @implementation UIErrorAlertView
 
 -(void)dismissWithClickedButtonIndex:(NSInteger)buttonIndex animated:(BOOL)animated
@@ -18,7 +17,6 @@
 @end
 
 @interface ModelViewController ()
-@property (strong, nonatomic) UIPopoverController *masterPopoverController;
 - (void)configureView;
 @end
 
@@ -34,10 +32,6 @@
     // Update the view.
     [self configureView];
   }
-
-  if (self.masterPopoverController != nil) {
-    [self.masterPopoverController dismissPopoverAnimated:YES];
-  }
 }
 
 - (void)configureView
@@ -50,9 +44,13 @@
 
 -(void)viewWillAppear:(BOOL)animated
 {
-  //if(self.initialModel != nil) {
-  if([[UIDevice currentDevice].model isEqualToString:@"iPad"] || [[UIDevice currentDevice].model isEqualToString:@"iPad Simulator"]) {
-    _loadingAlert = [[UIAlertView alloc] initWithTitle:@"Please wait..." message: @"The model is loading" delegate: self cancelButtonTitle: nil otherButtonTitles: nil];
+  if([[UIDevice currentDevice].model isEqualToString:@"iPad"] ||
+     [[UIDevice currentDevice].model isEqualToString:@"iPad Simulator"]) {
+    _loadingAlert = [[UIAlertView alloc] initWithTitle:@"Please wait..."
+                                               message: @"The model is loading"
+                                              delegate: self
+                                     cancelButtonTitle: nil
+                                     otherButtonTitles: nil];
     [_loadingAlert show];
   }
 }
@@ -87,19 +85,18 @@
   [self configureView];
   [_singleTap requireGestureRecognizerToFail:_doubleTap];
   scaleFactor = 1.;
-  _errors = [[NSMutableArray alloc] init];
   setObjCBridge((__bridge void*) self);
   [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(requestRender) name:@"requestRender" object:nil];
 
-  _runStopButton = [[UIBarButtonItem alloc] initWithTitle:@"Run" style:UIBarButtonItemStyleBordered target:self action:@selector(compute)];
-  //UIBarButtonItem *share = [[UIBarButtonItem alloc] initWithTitle:@"Share" style:UIBarButtonItemStyleBordered target:self action:@selector(share)];
-  if([[UIDevice currentDevice].model isEqualToString:@"iPad"] || [[UIDevice currentDevice].model isEqualToString:@"iPad Simulator"]){
-    UIBarButtonItem *model = [[UIBarButtonItem alloc] initWithTitle:@"Model list" style:UIBarButtonItemStyleBordered target:self action:@selector(showModelsList)];
-    [self.navigationItem setRightBarButtonItems:[NSArray arrayWithObjects:_runStopButton, model, /*share,*/ nil]];
+  _runStopButton = [[UIBarButtonItem alloc] initWithTitle:@"Run" style:UIBarButtonItemStylePlain target:self action:@selector(compute)];
+  if([[UIDevice currentDevice].model isEqualToString:@"iPad"] ||
+     [[UIDevice currentDevice].model isEqualToString:@"iPad Simulator"]){
+    UIBarButtonItem *model = [[UIBarButtonItem alloc] initWithTitle:@"Model list" style:UIBarButtonItemStylePlain target:self action:@selector(showModelsList)];
+    [self.navigationItem setRightBarButtonItems:[NSArray arrayWithObjects:_runStopButton, model, nil]];
   }
   else {
-    UIBarButtonItem *settings = [[UIBarButtonItem alloc] initWithTitle:@"Parameters" style:UIBarButtonItemStyleBordered target:self action:@selector(showSettings)];
-    [self.navigationItem setRightBarButtonItems:[NSArray arrayWithObjects:_runStopButton, settings, /*share,*/ nil]];
+    UIBarButtonItem *settings = [[UIBarButtonItem alloc] initWithTitle:@"Parameters" style:UIBarButtonItemStylePlain target:self action:@selector(showSettings)];
+    [self.navigationItem setRightBarButtonItems:[NSArray arrayWithObjects:_runStopButton, settings, nil]];
   }
 
   UIBarButtonItem *flexibleSpace = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemFlexibleSpace target:nil action:nil];
@@ -132,16 +129,8 @@
   [[UIApplication sharedApplication] endBackgroundTask: _computeBackgroundTaskIdentifier];
 }
 
--(void)share
-{
-  NSArray *dataToShare = @[[self.glView getGLScreenshot]];
-  UIActivityViewController *activityVC = [[UIActivityViewController alloc] initWithActivityItems:dataToShare applicationActivities:nil];
-  [self presentViewController:activityVC animated:YES completion:nil];
-}
-
 - (void)compute
 {
-  [_errors removeAllObjects];
   [_runStopButton setAction:@selector(stop)];
   [_runStopButton setTitle:@"Stop"];
   [_progressLabel setText:@""];
@@ -171,6 +160,7 @@
       }
       [[UIApplication sharedApplication] endBackgroundTask: _computeBackgroundTaskIdentifier];
       _computeBackgroundTaskIdentifier = UIBackgroundTaskInvalid;
+      [[NSNotificationCenter defaultCenter] postNotificationName:@"refreshParameters" object:nil];
     });
 
   dispatch_group_notify(group, queue, ^{
@@ -186,10 +176,6 @@
   [_progressLabel setHidden:YES];
   [_progressIndicator stopAnimating];
   [_progressIndicator setHidden:YES];
-  if(_errors.count > 0) {
-    _errorAlert = [[UIErrorAlertView alloc] initWithTitle:@"Gmsh/GetDP error" message:[_errors lastObject] delegate:self cancelButtonTitle:@"Hide" otherButtonTitles:@"Show more", nil];
-    [_errorAlert show];
-  }
 }
 
 - (void)stop
@@ -274,7 +260,8 @@
     [alert show];
     return;
   }
-  if([[UIDevice currentDevice].model isEqualToString:@"iPad"] || [[UIDevice currentDevice].model isEqualToString:@"iPad Simulator"]){
+  if([[UIDevice currentDevice].model isEqualToString:@"iPad"] ||
+     [[UIDevice currentDevice].model isEqualToString:@"iPad Simulator"]){
     AppDelegate *appDelegate = (AppDelegate *)[UIApplication sharedApplication].delegate;
     [UIView transitionWithView:appDelegate.window
                       duration:0.5
@@ -312,41 +299,11 @@
   return YES;
 }
 
-#pragma mark - Alert view
-
--(void)addError:(std::string)msg
-{
-  [_errors addObject:[NSString stringWithCString:msg.c_str() encoding:[NSString defaultCStringEncoding]]];
-}
-
--(void)alertView:(UIAlertView *)alertView clickedButtonAtIndex:(NSInteger)buttonIndex
-{
-  if(buttonIndex == 0) {
-    [_errors removeAllObjects];
-    return;
-  }
-  else [_errors removeLastObject];
-  if(_errors.count > 1)
-    _errorAlert = [[UIErrorAlertView alloc] initWithTitle:@"Gmsh/GetDP error" message:[_errors lastObject] delegate:self cancelButtonTitle:@"Hide" otherButtonTitles:@"Show more", nil];
-  else
-    _errorAlert = [[UIErrorAlertView alloc] initWithTitle:@"Gmsh/GetDP error" message:[_errors lastObject] delegate:self cancelButtonTitle:@"Hide" otherButtonTitles: nil];
-  [_errorAlert show];
-}
-
 #pragma mark - Split view
 
-- (void)splitViewController:(UISplitViewController *)splitController willHideViewController:(UIViewController *)viewController withBarButtonItem:(UIBarButtonItem *)barButtonItem forPopoverController:(UIPopoverController *)popoverController
+-(BOOL)splitViewController:(UISplitViewController *)svc shouldHideViewController:(UIViewController *)vc inOrientation:(UIInterfaceOrientation)orientation
 {
-  barButtonItem.title = NSLocalizedString(@"Parameters", @"Parameters");
-  [self.navigationItem setLeftBarButtonItem:barButtonItem];
-  self.masterPopoverController = popoverController;
-}
-
-- (void)splitViewController:(UISplitViewController *)splitController willShowViewController:(UIViewController *)viewController invalidatingBarButtonItem:(UIBarButtonItem *)barButtonItem
-{
-  // Called when the view is shown again in the split view, invalidating the button and popover controller.
-  [self.navigationItem setLeftBarButtonItem:nil animated:YES];
-  self.masterPopoverController = nil;
+	return NO;
 }
 
 void messageFromCpp (void *self, std::string level, std::string msg)
@@ -356,10 +313,13 @@ void messageFromCpp (void *self, std::string level, std::string msg)
     [[NSNotificationCenter defaultCenter] postNotificationName:@"refreshParameters" object:nil];
   }
   else if(level == "Progress"){
-    [(__bridge id)self performSelectorOnMainThread:@selector(setProgress:) withObject:[NSString stringWithCString:msg.c_str() encoding:[NSString defaultCStringEncoding]] waitUntilDone:YES];
+    [(__bridge id) self performSelectorOnMainThread:@selector(setProgress:)
+                                         withObject:[Utils getStringFromCString:msg.c_str()] waitUntilDone:YES];
+  }
+  else if(level == "Error"){
+    [(__bridge id) self performSelectorOnMainThread:@selector(showError:)
+                                         withObject:[Utils getStringFromCString:msg.c_str()] waitUntilDone:YES];
   }
-  else if(level == "Error")
-    [(__bridge id)self addError:msg];
 }
 
 -(void)setProgress:(NSString *)progress
@@ -367,6 +327,19 @@ void messageFromCpp (void *self, std::string level, std::string msg)
   [_progressLabel setText:progress];
 }
 
+-(void)showError:(NSString *)msg
+{
+  // only show first error
+  if(_errorAlert != nil && _errorAlert.visible) return;
+  // remove document path from error message
+  NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
+  NSString *docPath = [[paths objectAtIndex:0] stringByAppendingString:@"/"];
+  NSString *str = [msg stringByReplacingOccurrencesOfString:docPath withString:@""];
+  _errorAlert = [[UIErrorAlertView alloc] initWithTitle:@"Error" message:str delegate:self
+                                      cancelButtonTitle:@"Dismiss" otherButtonTitles:nil, nil];
+  [_errorAlert show];
+}
+
 -(void)handleProgressIndicatorTap:(id)sender
 {
   [_progressLabel setHidden:!_progressLabel.hidden];
@@ -381,7 +354,7 @@ void getBitmap(void *self, const char *text, int textsize, unsigned char **map,
 {
   UILabel *lbl = [[UILabel alloc] initWithFrame:CGRectMake(0, 0, 1024, 7*textsize/6)];
   lbl.font = [UIFont systemFontOfSize:textsize];
-  [lbl setText:[NSString stringWithCString:text  encoding:[NSString defaultCStringEncoding]]];
+  [lbl setText:[Utils getStringFromCString:text]];
   [lbl setBackgroundColor:[UIColor clearColor]];
   CGSize lblSize = [[lbl text] sizeWithAttributes:@{NSFontAttributeName:[lbl font]}];
   *realWidth = lblSize.width;
